==> swscanner_0.1.8.orig.tar.gz: swscanner-0.1.8/src/gpslog.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Ivan Forcada Atienza                            *
 *   ivan@forcada.info                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef GPSLOG_H
#define GPSLOG_H

#include <apentry.h>

#include <qfile.h>
#include <qfiledialog.h>
#include <qmessagebox.h>
#include <qvariant.h>

#include <klocale.h>
#include <errno.h>

/**
@author Ivn Forcada Atienza
*/

class gpslog{
private:
	QFile logfile;	// Qt file descriptor
	QString filename;

public:
	gpslog();
 	~gpslog();
	void addLine(QString line);
	void addLine(APEntry * ap, double longi, double lati);
	int open(QString filename = "");
	void close();
};

#endif

==> swscanner_0.2.2.orig.tar.gz: swscanner-0.2.2/src/gpslog.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Ivan Forcada Atienza                            *
 *   ivan@forcada.info                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef GPSLOG_H
#define GPSLOG_H

#include <apentry.h>

#include <qfile.h>
#include <qvariant.h>

#include <klocale.h>
#include <kfiledialog.h>
#include <kmessagebox.h>

#include <errno.h>

#include "config.h"

/**
@author Ivn Forcada Atienza
*/

class gpslog{
private:
	QFile logfile;	// Qt file descriptor
	QString filename;

public:
	gpslog();
 	~gpslog();
	void addLine(QString line);
	void addLine(APEntry * ap, double longi, double lati);
	int open(QString filename = "");
	QString getFileName() { return logfile.name(); };
	void close();

private:
	bool openLogFile();
	
};

#endif
